==> plugin-chart-echarts-0.17.46.tgz: package/esm/Treemap/transformProps.js <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { CategoricalColorNamespace, getMetricLabel, getNumberFormatter, getTimeFormatter } from '@superset-ui/core';
import { groupBy, isNumber, transform } from 'lodash';
import { DEFAULT_FORM_DATA as DEFAULT_TREEMAP_FORM_DATA, EchartsTreemapLabelType } from './types';
import { formatSeriesName } from '../utils/series';
import { defaultTooltip } from '../defaults';
export function formatLabel({
  params,
  labelType,
  numberFormatter
}) {
  const {
    name = '',
    value
  } = params;
  const formattedValue = numberFormatter(value);

  switch (labelType) {
    case EchartsTreemapLabelType.Key:
      return name;

    case EchartsTreemapLabelType.Value:
      return formattedValue;

    case EchartsTreemapLabelType.KeyValue:
      return `${name}: ${formattedValue}`;

    default:
      return name;
  }
}
export default function transformProps(chartProps) {
  const {
    formData,
    height,
    queriesData,
    width
  } = chartProps;
  const {
    data = []
  } = queriesData[0];
  const {
    colorScheme,
    groupby = [],
    metrics = [],
    labelType,
    labelPosition,
    numberFormat,
    dateFormat,
    showLabels,
    showUpperLabels,
    nodeClick,
    roam
  } = { ...DEFAULT_TREEMAP_FORM_DATA,
    ...formData
  };
  const colorFn = CategoricalColorNamespace.getScale(colorScheme);
  const numberFormatter = getNumberFormatter(numberFormat);

  const formatter = params => formatLabel({
    params,
    numberFormatter,
    labelType
  });

  const transformer = (data, groupbyData, metric, depth) => {
    const [currGroupby, ...restGroupby] = groupbyData;
    const currGrouping = groupBy(data, currGroupby);

    if (!restGroupby.length) {
      return transform(currGrouping, (result, value, key) => {
        (value != null ? value : []).forEach(datum => {
          const name = formatSeriesName(key, {
            numberFormatter,
            timeFormatter: getTimeFormatter(dateFormat)
          });
          result.push({
            name,
            value: isNumber(datum[metric]) ? datum[metric] : 0
          });
        });
      }, []);
    }

    const sortedData = transform(currGrouping, (result, value, key) => {
      const name = formatSeriesName(key, {
        numberFormatter,
        timeFormatter: getTimeFormatter(dateFormat)
      });
      const children = transformer(value, restGroupby, metric, depth + 1);
      result.push({
        name,
        children,
        value: children.reduce((prev, cur) => prev + cur.value, 0)
      });
      result.sort((a, b) => b.value - a.value);
    }, []); // sort according to the area and then take the color value in order

    return sortedData.map(child => ({ ...child,
      colorSaturation: [0.4, 0.7],
      itemStyle: {
        borderColor: showUpperLabels ? colorFn(`${child.name}_${depth - 1}`) : '#fff',
        color: colorFn(`${child.name}_${depth}_${showUpperLabels}`),
        borderWidth: 2,
        gapWidth: 2
      }
    }));
  };

  const metricsLabel = metrics.map(metric => getMetricLabel(metric));
  const initialDepth = 1;
  const transformedData = metricsLabel.map(metricLabel => ({
    name: metricLabel,
    colorSaturation: [0.4, 0.7],
    itemStyle: {
      borderColor: showUpperLabels ? colorFn(`${metricLabel}_${initialDepth}`) : '#fff',
      borderWidth: 2,
      gapWidth: 2
    },
    children: transformer(data, groupby, metricLabel, initialDepth)
  })); // set a default color when metric values are 0 over all.

  const levels = [{
    upperLabel: {
      show: false
    },
    label: {
      show: false
    },
    itemStyle: {
      color: CategoricalColorNamespace.getColor()
    }
  }];
  const series = [{
    type: 'treemap',
    animation: false,
    width: '100%',
    height: '100%',
    nodeClick,
    roam,
    breadcrumb: {
      show: false,
      emptyItemWidth: 25
    },
    squareRatio: 0.5 * (1 + Math.sqrt(5)),
    // golden ratio
    emphasis: {
      label: {
        show: true
      }
    },
    levels,
    label: {
      show: showLabels,
      position: labelPosition,
      formatter,
      color: '#000',
      fontSize: 11
    },
    upperLabel: {
      show: showUpperLabels,
      formatter,
      textBorderColor: 'transparent',
      fontSize: 11
    },
    data: transformedData
  }];
  const echartOptions = {
    tooltip: { ...defaultTooltip,
      trigger: 'item',
      formatter: params => formatLabel({
        params,
        numberFormatter,
        labelType: EchartsTreemapLabelType.KeyValue
      })
    },
    series
  };
  return {
    width,
    height,
    echartOptions
  };
}

==> plugin-chart-echarts-0.17.47.tgz: package/esm/Treemap/transformProps.js <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { CategoricalColorNamespace, getMetricLabel, getNumberFormatter, getTimeFormatter } from '@superset-ui/core';
import { groupBy, isNumber, transform } from 'lodash';
import { DEFAULT_FORM_DATA as DEFAULT_TREEMAP_FORM_DATA, EchartsTreemapLabelType } from './types';
import { formatSeriesName } from '../utils/series';
import { defaultTooltip } from '../defaults';
export function formatLabel({
  params,
  labelType,
  numberFormatter
}) {
  const {
    name = '',
    value
  } = params;
  const formattedValue = numberFormatter(value);

  switch (labelType) {
    case EchartsTreemapLabelType.Key:
      return name;

    case EchartsTreemapLabelType.Value:
      return formattedValue;

    case EchartsTreemapLabelType.KeyValue:
      return `${name}: ${formattedValue}`;

    default:
      return name;
  }
}
export function formatTooltip({
  params,
  numberFormatter
}) {
  const {
    value,
    treePathInfo
  } = params;
  const formattedValue = numberFormatter(value);
  const treePath = (treePathInfo != null ? treePathInfo : []).map(pathInfo => (pathInfo == null ? void 0 : pathInfo.name) || '').filter(path => path !== ''); // the 1st tree path is metric label

  const metricLabel = treePath.shift() || ''; // groupby1/groupby2/...
  // metric: value

  return [`<div>${treePath.join(' ▸ ')}</div>`, `${metricLabel}: ${formattedValue}`].join('');
}
export default function transformProps(chartProps) {
  const {
    formData,
    height,
    queriesData,
    width
  } = chartProps;
  const {
    data = []
  } = queriesData[0];
  const {
    colorScheme,
    groupby = [],
    metrics = [],
    labelType,
    labelPosition,
    numberFormat,
    dateFormat,
    showLabels,
    showUpperLabels,
    nodeClick,
    roam
  } = { ...DEFAULT_TREEMAP_FORM_DATA,
    ...formData
  };
  const colorFn = CategoricalColorNamespace.getScale(colorScheme);
  const numberFormatter = getNumberFormatter(numberFormat);

  const formatter = params => formatLabel({
    params,
    numberFormatter,
    labelType
  });

  const transformer = (data, groupbyData, metric, depth) => {
    const [currGroupby, ...restGroupby] = groupbyData;
    const currGrouping = groupBy(data, currGroupby);

    if (!restGroupby.length) {
      return transform(currGrouping, (result, value, key) => {
        (value != null ? value : []).forEach(datum => {
          const name = formatSeriesName(key, {
            numberFormatter,
            timeFormatter: getTimeFormatter(dateFormat)
          });
          result.push({
            name,
            value: isNumber(datum[metric]) ? datum[metric] : 0
          });
        });
      }, []);
    }

    const sortedData = transform(currGrouping, (result, value, key) => {
      const name = formatSeriesName(key, {
        numberFormatter,
        timeFormatter: getTimeFormatter(dateFormat)
      });
      const children = transformer(value, restGroupby, metric, depth + 1);
      result.push({
        name,
        children,
        value: children.reduce((prev, cur) => prev + cur.value, 0)
      });
      result.sort((a, b) => b.value - a.value);
    }, []); // sort according to the area and then take the color value in order

    return sortedData.map(child => ({ ...child,
      colorSaturation: [0.4, 0.7],
      itemStyle: {
        borderColor: showUpperLabels ? colorFn(`${child.name}_${depth - 1}`) : '#fff',
        color: colorFn(`${child.name}_${depth}_${showUpperLabels}`),
        borderWidth: 2,
        gapWidth: 2
      }
    }));
  };

  const metricsLabel = metrics.map(metric => getMetricLabel(metric));
  const initialDepth = 1;
  const transformedData = metricsLabel.map(metricLabel => ({
    name: metricLabel,
    colorSaturation: [0.4, 0.7],
    itemStyle: {
      borderColor: showUpperLabels ? colorFn(`${metricLabel}_${initialDepth}`) : '#fff',
      borderWidth: 2,
      gapWidth: 2
    },
    children: transformer(data, groupby, metricLabel, initialDepth)
  })); // set a default color when metric values are 0 over all.

  const levels = [{
    upperLabel: {
      show: false
    },
    label: {
      show: false
    },
    itemStyle: {
      color: CategoricalColorNamespace.getColor()
    }
  }];
  const series = [{
    type: 'treemap',
    animation: false,
    width: '100%',
    height: '100%',
    nodeClick,
    roam,
    breadcrumb: {
      show: false,
      emptyItemWidth: 25
    },
    squareRatio: 0.5 * (1 + Math.sqrt(5)),
    // golden ratio
    emphasis: {
      label: {
        show: true
      }
    },
    levels,
    label: {
      show: showLabels,
      position: labelPosition,
      formatter,
      color: '#000',
      fontSize: 11
    },
    upperLabel: {
      show: showUpperLabels,
      formatter,
      textBorderColor: 'transparent',
      fontSize: 11
    },
    data: transformedData
  }];
  const echartOptions = {
    tooltip: { ...defaultTooltip,
      trigger: 'item',
      formatter: params => formatTooltip({
        params,
        numberFormatter
      })
    },
    series
  };
  return {
    width,
    height,
    echartOptions
  };
}
